@@ -30,18 +30,19 @@ void DownloadManager::setDownloadQuality(const QString &quality) {
 void DownloadManager::getVideoUrl(const QString &playerUrl) {
     QString url = playerUrl;
     QString videoId = url.split("v=").last().split("&").first();
-    QString pageUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
-    downloadReply = nam->get(QNetworkRequest(QUrl(pageUrl)));
-    connect(downloadReply, SIGNAL(finished()), this, SLOT(parseVideoPage()));
+    QString pageUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
+    QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+    QNetworkRequest request;
+    request.setUrl(QUrl(pageUrl));
+    connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(parseVideoPage(QNetworkReply*)));
+    manager->get(request);
 }
 
-void DownloadManager::parseVideoPage() {
-    if (downloadReply->error()) {
-        emit statusChanged("failed");
-        return;
-    }
+void DownloadManager::parseVideoPage(QNetworkReply *reply) {
+    QNetworkAccessManager *manager = qobject_cast<QNetworkAccessManager*>(sender());
+
     QMap<int, QString> formats;
-    QString response(QByteArray::fromPercentEncoding(downloadReply->readAll()));
+    QString response(QByteArray::fromPercentEncoding(reply->readAll()));
     int pos = response.indexOf("fmt_stream_map=url=") + 19;
     int pos2 = response.indexOf("&cc_font", pos);
     int pos3 = response.indexOf("&leanback", pos);
@@ -74,6 +75,8 @@ void DownloadManager::parseVideoPage() {
         emit gotVideoUrl(QUrl(videoUrl));
         emit qualityChanged(quality);
     }
+    reply->deleteLater();
+    manager->deleteLater();
 }
 
 void DownloadManager::getDMVideoUrl(const QString &link) {
