@@ -25,7 +25,7 @@ function getYouTubeVideos() {
                 var res;
                 for (var i = 0; i < results.feed.entry.length; i++) {
                     res = results.feed.entry[i];
-                    if ((res.app$control) && (res.app$control.yt$state.reasonCode != "limitedSyndication")) {
+                    if ((res.app$control) && (res.app$control.yt$state) && (res.app$control.yt$state.reasonCode != "limitedSyndication")) {
                         videoListModel.totalResults--;
                     }
                     else {
